==> peony-extensions_4.10.0.0.orig.tar.gz: peony-extensions-4.10.0.0/peony-drive-rename/translations/peony-drive-rename_zh_HK.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_Hant">
<context>
    <name>Peony::DriveRename</name>
    <message>
        <source>drive rename</source>
        <translation type="vanished">设备重命名</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="165"/>
        <location filename="../drive-rename.cpp" line="177"/>
        <source>Rename</source>
        <translation>重新命名</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="177"/>
        <source>Device name:</source>
        <translation>裝置名稱：</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="181"/>
        <location filename="../drive-rename.cpp" line="189"/>
        <location filename="../drive-rename.cpp" line="195"/>
        <location filename="../drive-rename.cpp" line="208"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="181"/>
        <source>Renaming cannot start with a decimal point, Please re-enter!</source>
        <translation>重命名不能以小數點開始，請重新輸入！</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="189"/>
        <source>The device name exceeds the character limit, rename failed!</source>
        <translation>設備名稱超過了字元限制，重命名失敗！</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="195"/>
        <source>Renaming will unmount the device. Do you want to continue?</source>
        <translation>重命名將會卸載設備，是否繼續？</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="208"/>
        <source>The device may not support the rename operation, rename failed!</source>
        <translation>可能設備不支援重命名操作，重命名失敗！</translation>
    </message>
    <message>
        <source>Failed to rename!</source>
        <translation type="vanished">重命名失败！</translation>
    </message>
</context>
<context>
    <name>Peony::DriveRenamePlugin</name>
    <message>
        <location filename="../driverenameplugin.h" line="21"/>
        <source>drive rename</source>
        <translation>設備重新命名</translation>
    </message>
</context>
<context>
    <name>Peony::DriverAction</name>
    <message>
        <source>Send to a removable device</source>
        <translation type="vanished">发送到移动设备</translation>
    </message>
</context>
<context>
    <name>Peony::SendToPlugin</name>
    <message>
        <source>Send to a removable device</source>
        <translation type="vanished">发送到移动设备</translation>
    </message>
</context>
</TS>

==> peony-extensions_4.20.0.0.orig.tar.gz: peony-extensions-4.20.0.0/peony-drive-rename/translations/peony-drive-rename_zh_HK.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_Hant">
<context>
    <name>Peony::DriveRename</name>
    <message>
        <source>drive rename</source>
        <translation type="vanished">设备重命名</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="181"/>
        <location filename="../drive-rename.cpp" line="193"/>
        <source>Rename</source>
        <translation>重新命名</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="193"/>
        <source>Device name:</source>
        <translation>裝置名稱：</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="197"/>
        <location filename="../drive-rename.cpp" line="205"/>
        <location filename="../drive-rename.cpp" line="211"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="197"/>
        <source>Renaming cannot start with a decimal point, Please re-enter!</source>
        <translation>重命名不能以小數點開始，請重新輸入！</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="205"/>
        <source>The device name exceeds the character limit, rename failed!</source>
        <translation>設備名稱超過了字元限制，重命名失敗！</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="211"/>
        <source>Renaming will unmount the device. Do you want to continue?</source>
        <translation>重命名將會卸載設備，是否繼續？</translation>
    </message>
    <message>
        <source>The device may not support the rename operation, rename failed!</source>
        <translation type="vanished">可能設備不支援重命名操作，重命名失敗！</translation>
    </message>
    <message>
        <source>Failed to rename!</source>
        <translation type="vanished">重命名失败！</translation>
    </message>
</context>
<context>
    <name>Peony::DriveRenamePlugin</name>
    <message>
        <source>drive rename</source>
        <translation type="vanished">設備重新命名</translation>
    </message>
    <message>
        <location filename="../driverenameplugin.h" line="41"/>
        <source>Drive rename</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Peony::DriverAction</name>
    <message>
        <source>Send to a removable device</source>
        <translation type="vanished">发送到移动设备</translation>
    </message>
</context>
<context>
    <name>Peony::SendToPlugin</name>
    <message>
        <source>Send to a removable device</source>
        <translation type="vanished">发送到移动设备</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../drive-rename.cpp" line="343"/>
        <source>Warning</source>
        <translation type="unfinished">警告</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="343"/>
        <source>The device may not support the rename operation, rename failed!</source>
        <translation type="unfinished">可能設備不支援重命名操作，重命名失敗！</translation>
    </message>
</context>
</TS>
